from netbox.api.routers import NetBoxRouter
from . import views

app_name = 'ptuevents'

router = NetBoxRouter()
router.register('ptuevents', views.PTUEventListViewSet)
router.register('ptueventrelation', views.PTUEventRelationListViewSet)
router.register('ptueventassignment', views.PTUEventAssignmentViewSet)
router.register('pt-app-systems', views.PTAppSystemViewSet)
router.register('pt-app-system-assignment', views.PTAppSystemAssignmentViewSet)
router.register('ptusers', views.PTUsersListViewSet)
router.register('ptworkstations', views.PTWorkstationsListViewSet)

urlpatterns = router.urls

# print(router.urls)



from .serializers import PTAppSystemSerializer, PTAppSystemAssignmentSerializer
from netbox.api.viewsets import NetBoxModelViewSet
from ..models import PTUEventRelation, PTUEvent, PTUEventAssignment, PTAppSystem, PTAppSystemAssignment, PTUsers, PTWorkstations
from .serializers import PTUEventRelationSerializer, PTUEventSerializer, PTUEventAssignmentSerializer, PTUsersSerializer, PTWorkstationsSerializer
from .. import filtersets


class PTUEventListViewSet(NetBoxModelViewSet):
    queryset = PTUEvent.objects.prefetch_related('tags')
    serializer_class = PTUEventSerializer


class PTUEventRelationListViewSet(NetBoxModelViewSet):
    queryset = PTUEventRelation.objects.prefetch_related('tags')
    serializer_class = PTUEventRelationSerializer


class PTUEventAssignmentViewSet(NetBoxModelViewSet):
    queryset = PTUEventAssignment.objects.prefetch_related(
        'object', 'ptuevent', 'relation')
    serializer_class = PTUEventAssignmentSerializer
    filterset_class = filtersets.PTUEventAssignmentFilterSet


class PTAppSystemViewSet(NetBoxModelViewSet):
    queryset = PTAppSystem.objects.prefetch_related('tenant', 'tags')
    serializer_class = PTAppSystemSerializer
    filterset_class = filtersets.PTAppSystemFilterSet


class PTAppSystemAssignmentViewSet(NetBoxModelViewSet):
    queryset = PTAppSystemAssignment.objects.prefetch_related(
        'object', 'app_system')
    serializer_class = PTAppSystemAssignmentSerializer
    filterset_class = filtersets.PTAppSystemAssignmentFilterSet


class PTUsersListViewSet(NetBoxModelViewSet):
    queryset = PTUsers.objects.prefetch_related('tags')
    serializer_class = PTUsersSerializer


class PTWorkstationsListViewSet(NetBoxModelViewSet):
    queryset = PTWorkstations.objects.prefetch_related('tags')
    serializer_class = PTWorkstationsSerializer

